# Generated by Django 4.0.4 on 2022-05-04 12:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("shop", "0009_product_slug"),
    ]

    operations = [
        migrations.AlterField(
            model_name="discountcode",
            name="categories",
            field=models.ManyToManyField(
                blank=True,
                related_name="%(class)s_related",
                to="shop.category",
                verbose_name="Categories",
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="billing_detail_state",
            field=models.CharField(
                blank=True, max_length=100, verbose_name="State/Region"
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="shipping_detail_state",
            field=models.CharField(
                blank=True, max_length=100, verbose_name="State/Region"
            ),
        ),
        migrations.AlterField(
            model_name="product",
            name="related_products",
            field=models.ManyToManyField(
                blank=True, to="shop.product", verbose_name="Related products"
            ),
        ),
        migrations.AlterField(
            model_name="product",
            name="upsell_products",
            field=models.ManyToManyField(
                blank=True, to="shop.product", verbose_name="Upsell products"
            ),
        ),
        migrations.AlterField(
            model_name="sale",
            name="categories",
            field=models.ManyToManyField(
                blank=True,
                related_name="%(class)s_related",
                to="shop.category",
                verbose_name="Categories",
            ),
        ),
    ]
